#include "FastPWM.h"

void Init_FastPWM(uint8_t Prescaler, bool InvertingMode)
{	
	// Configure the waveform generation in mode 3 (Fast PWM)
	CLEARBIT(TCCR2B,WGM22);
	SETBIT(TCCR2A,WGM21);
	SETBIT(TCCR2A,WGM20);
	
	if (InvertingMode)
	{
		// Clear OC2A on compare match, set OC2A at BOTTOM (non-inverting mode)
		SETBIT(TCCR2A,COM2A0);
		SETBIT(TCCR2A,COM2A1);
		// Clear OC2B on compare match, set OC2B at BOTTOM (non-inverting mode)
		SETBIT(TCCR2A,COM2B0);
		SETBIT(TCCR2A,COM2B1);		
	}
	else
	{	
		// Set OC2A on compare match, clear OC2A at BOTTOM (inverting mode)
		CLEARBIT(TCCR2A,COM2A0);
		SETBIT(TCCR2A,COM2A1);	
		// Set OC2B on compare match, clear OC2B at BOTTOM (inverting mode)
		CLEARBIT(TCCR2A,COM2B0);
		SETBIT(TCCR2A,COM2B1);
	}	
	
	// Set the prescaler to the expected value
	CLEARBITS(TCCR2B,0x7);
	SETBITS(TCCR2B,Prescaler);	
}


// Set the duty cycle for PWM A
// pin 15 of the ATmega168
void SetDutyCycleA(uint8_t CompareRegister)
{
	OCR2A=CompareRegister;	
}

// Set the duty cycle for PWM B 
// pin 1 of the ATmega168
void SetDutyCycleB(uint8_t CompareRegister)
{
	OCR2B=CompareRegister;
}