#ifndef FASTPWM_H_
#define FASTPWM_H_

/*
 * FastPWM.h
 *
 * Created: 23/10/2012 08:31:41
 *  Author: robot
 */ 



#include <avr/io.h>
#include "macro.h"


// Prescaler constants
// Fpwm=F_CPU/(PRESCALER*256)

// Prescaler = 1
// Fpwm=31.250 kHz at F_CPU=8MHz
// Fpwm=78.125 kHz at F_CPU=20MHz
#define			FPWM_PRESCALER_1			1	

// Prescaler = 1/8
// Fpwm=9.765 kHz at F_CPU=8MHz
// Fpwm=3.906 kHz at F_CPU=20MHz	
#define			FPWM_PRESCALER_8			2

// Prescaler = 1/32
// Fpwm=976.5 Hz  at F_CPU=8MHz
// Fpwm=2.441 kHz at F_CPU=20MHz
#define			FPWM_PRESCALER_32			3

// Prescaler = 1/64
// Fpwm=448.2 Hz  at F_CPU=8MHz
// Fpwm=1.220 kHz at F_CPU=20MHz
#define			FPWM_PRESCALER_64			4

#define			FPWM_PRESCALER_128			5
#define			FPWM_PRESCALER_256			6
#define			FPWM_PRESCALER_1024			7


// Inverting/non inverting mode constants
#define			FPWM_NON_INVERTING			false
#define			FPWM_INVERTING_MODE			true


// Initialize the fast PWM mode
void Init_FastPWM(uint8_t Prescaler, bool InvertingMode=FPWM_NON_INVERTING);


// Set the duty cycle for PWM B
// pin 15 of the ATmega168
void SetDutyCycleA(uint8_t CompareRegister);


// Set the duty cycle for PWM B
// pin 1 of the ATmega168
void SetDutyCycleB(uint8_t CompareRegister);




#endif /* FASTPWM_H_ */