/*
 * Matrix_5x7.cpp
 *
 * Created: 23/10/2012 14:21:31
 *  Author: robot
 */

#include "Matrix_5x7.h"


/*!
    \brief  Array containing the data to display
            7 row containing 5 usefull bools
*/
uint8_t SharedMatrixData_7x5[7];



/*!
    \brief  Initialize the matrix display (timer and interrupt)
*/
void Init_Matrix_5x7()
{
    // Set initial value of the display (set all the led off)
    for (uint8_t i=0;i<7;i++)
        SharedMatrixData_7x5 [i]=0;

    // Initialize Timer/Counter 2 in fast PWM mode without prescaler
    Init_FastPWM(FPWM_PRESCALER_1);

    // Enable Interrupt TimerCounter0 Compare Match A (SIG_OUTPUT_COMPARE0A)
    TIMSK0	= _BV(OCIE0A);

    // Mode=CTC
    TCCR0A	= _BV(WGM01);

    // Clock/1024, 0.001024 seconds per tick
    TCCR0B	= _BV(CS00) | _BV(CS01);

    // 56KHz pour 8MHz
    OCR0A	= 200;


}







// ########################################## Mes fonctions ##################################################



void SetData_7x5(uint8_t MatrixData[5])                 // fonction de base en matrice à la verticale.
{                                                       // Affiche un seul caractère de la table font_5x7.h
    // For each row
    for (uint8_t r=0;r<7;r++)
    {
        uint8_t CurData=0;
        for (uint8_t c=0;c<5;c++)
        {
            if (MatrixData[4-c] & (1<<r))
                CurData |= 1<<c;

        }
        SharedMatrixData_7x5[r]=CurData;

    }
}



void SetData_2x_3x5_Char(uint8_t Lettre1,uint8_t Lettre2)              // à utiliser pour afficher 2 caractères.
{
    uint8_t Mat1[5];


    for (int i=0;i<5;i++)
    {
        Mat1[i]=Font_3x5[(Lettre2)*5+i] |( Font_3x5[(Lettre1)*5+i] << 4) ;

    }

    SetData_7x5(Mat1);

} // affichera     > Lettre1 Lettre2     sur l'afficheur


void SetData_2x_3x5_DEC(uint8_t Value, int type)  // A utiliser pour afficher un nombre :
// type correspond au type d'affichage que l'on souhaite : si type == 1 => affichage décimal sinon affichage héxadécimal
{
    uint8_t Mat1[5], unite, dizaine;        // Value2 Unité  --- Value1 Décimale

    if(type==1)                 // décimal si type est à 1 !!!
    {
        unite = Value % 10;
        dizaine = Value/10;
    }

    else                        // HEXA si type est autre que 1 !!!
    {
        unite = Value % 16;
        dizaine = Value/16;
    }

    for (int i=0;i<5;i++)       // finis par afficher les dizaines et les unités
    {
        Mat1[i]=Font_3x5[(unite)*5+i] |( Font_3x5[(dizaine)*5+i] << 4) ;

    }

    SetData_7x5(Mat1);

}




// ######################################### Fin Mes fonctions ##########################################################

















void PutChar(char Ch)
{
    SetData_7x5((uint8_t*)&Font[(Ch-FONT_MIN)*5]);
}




/*!
    \brief  Command the multiplexer to select a given row
    \param  nRow : index of the row from 0 to 6 [0;6]
*/
void SelectRow(uint8_t nRow)
{
    PORTB= (PORTB&~0x07) | (nRow & 0x07);
}



/*!
    \brief  Set the state of the first column  (turn a led on or off)
    \param  State : status of the column (0 or 1)
*/
void P_C1(bool State)
{
    if (State)
        PORTC=PORTC & ~0x02;
    else
        PORTC=PORTC | 0x02;

}



/*!
    \brief  Set the state of the second column (turn a led on or off)
    \param  State : status of the column (0 or 1)
*/
void P_C2(bool State)
{
    if (State)
        PORTC=PORTC & ~0x04;
    else
        PORTC=PORTC | 0x04;
}



/*!
    \brief  Set the state of the third column (turn a led on or off)
    \param  State : status of the column (0 or 1)
*/
void P_C3(bool State)
{
    if (State)
        PORTC=PORTC & ~0x08;
    else
        PORTC=PORTC | 0x08;

}




/*!
    \brief  Set the state of the fourth column (turn a led on or off)
    \param  State : status of the column (0 or 1)
*/
void P_C4(bool State)
{
    if (State)
        PORTC=PORTC & ~0x01;
    else
        PORTC=PORTC | 0x01;
}




/*!
    \brief  Set the state of the fifth column (turn a led on or off)
    \param  State : status of the column (0 or 1)
*/
void P_C5(bool State)
{
    if (State)
        PORTD=PORTD & ~0x04;
    else
        PORTD=PORTD | 0x04;
}



/*!
    \brief  Set the value of all the columns
    \param  Data is the data used to control the column
*/
void SetDataCol(uint8_t Data)
{
    P_C1(Data&0x10);
    P_C2(Data&0x08);
    P_C3(Data&0x04);
    P_C4(Data&0x02);
    P_C5(Data&0x01);
}



/*!
    \brief  Interrupt Service Routine, called everytime the timer overflow
*/
ISR(SIG_OUTPUT_COMPARE0A)
{
    static uint8_t nRow=0;
    // unselect any row
    SelectRow(7);
    // Place the data on the columns
    SetDataCol(SharedMatrixData_7x5[nRow]);
    // Select the current row
    SelectRow(nRow);

    // Go to the next row
    if (++nRow==7) nRow=0;
}
