/*
    Fuses configuration :
        Extended : 	0xF8
        High : 		0XDF
        Low : 		0xE6
*/


#include <avr/io.h>
#include <util/delay.h>
#include "FastPWM.h"
#include "macro.h"
#include "Matrix_5x7.h"
#include "string.h"
#include <Wire.h>




// I2C address of the display
#define         I2C_ADDRESS_DISPLAY             0x50



//  Fonction appelée par l'interruption quand une trame est reçu.
//  Gère l'appelle des autres fonctions systèmes.
void receiveEvent( int howMany);



// Gére l'affichage des balises sur l'écran
void Affiche_Balises(char NBr);



int main()
{
    // PORTB = TOSC2 | TOSC1 | SCK | MISO | MOSI | C | B | A
    // Set A, B and C as output
    DDRB=DDRB|0x07;
    PORTB=0;

    // PORTC = NC | NC | SCL | SDA | P_C3 | P_C2 | PC_1 | PC_4
    // Set PC_1, PC_2, PC_3, PC_4 as output
    DDRC=DDRC|0x0F;
    PORTC=0;

    // PORTD = NC | NC | NC | NC | PWM | P_C5 | TX | RX
    // Set PWM and PC_5 as output
    DDRD=DDRD|0x0C;
    PORTD=0;

    // Initialize the matrix display
    Init_Matrix_5x7();

    //Enable Global Interrupts
    sei();

    // Set duty cycle at full lumnosity
    SetDutyCycleB(0xFF);

    // Initialisation de la liaison I2C avec l'adresse du module
    Wire.begin(I2C_ADDRESS_DISPLAY);

    // Interruption qui à la réception d'une trame I2C appelle la fonction receiveEvent
    Wire.onReceive(receiveEvent);

    // boucle du programme principal.
    // Ne fait rien, tout se passe dans l'interruption
    while(1);
}






/*!
    \brief  Permet de gérer l'affichage des balises
*/
void Affiche_Balises(char NBr)
{
    // Crée un tableau vide
    uint8_t Tab[]={0x00, 0x00, 0x00, 0x00, 0x00};

    // Test pour balayer l'ensemble des 64 possibilités d'affichage des balises.
    if(NBr & 0x01) Tab[0]|=0x01;
    if(NBr & 0x02) Tab[2]|=0x01;
    if(NBr & 0x04) Tab[4]|=0x01;
    if(NBr & 0x08) Tab[0]|=0x40;
    if(NBr & 0x10) Tab[2]|=0x40;
    if(NBr & 0x20) Tab[4]|=0x40;

    // affichage du contenu de Tab :  correspond aux balises allumées à NL1
    SetData_7x5(Tab);
}




/*!
    \brief  Vecteur d'interruption pour la réceptionde trame I2C
*/
void receiveEvent( int howMany)
{
    // Get value from the I2C bus
    unsigned char Value=Wire.read();


    // Affiche nombre compris entre 0 et 99 en décimal
    if(Value<100)
    {
        SetData_2x_3x5_DEC(Value,1);
        return;
    }

    // Affiche Bl pour bleu
    if(Value == 125)
    {
        SetData_2x_3x5_Char(11,18);
        return;
    }

    // Affiche Re pour Rouge
    if(Value == 126)
    {
        SetData_2x_3x5_Char(19,14);
        return;
    }

    // Affiche OK
    if(Value == 127)
    {
        SetData_2x_3x5_Char(17,16);
        return;
    }


    // Appelle la gestions des balises
    if(Value>=128 && Value<192)
    {
        Affiche_Balises(Value);
        return;
    }

    // Donnée non connue, l'écran est effacé
    uint8_t Tab[]={0x00, 0x00, 0x00, 0x00, 0x00};
    SetData_7x5(Tab);
}
